@@ -7,9 +7,11 @@ import os
 
 LANGUAGE = os.environ.get("SELENIUM-ODOO-PAGE-LANGUAGE", "en")
 TERMS = {
-    "Create and Edit...": "Créer et modifier...",
-    "Create Invoice": "Créer une facture",
-    "Confirm": "Confirmer",
+    "fr": {
+        "Create and Edit...": "Créer et modifier...",
+        "Create Invoice": "Créer une facture",
+        "Confirm": "Confirmer",
+    },
 }
 
 
